# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
#
# Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
# copying or use of this file, via any medium, is strictly prohibited.
# Proprietary and confidential. You may not use this file except in compliance
# with the License. You may obtain a copy of the License at
#
#     https://q-ctrl.com/terms
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS. See the
# License for the specific language.
"""Module for OptimizationVariableNode."""
from typing import Any

from qctrlcommons.node.base import Node


class GetAttributeNode(Node):
    """Helper class to allow evaluate the value of the node by accessing attributes."""

    name = "getattr"

    def _evaluate_node(
        self, execution_context: "ExecutionContext", args, kwargs
    ) -> Any:
        """Evaluate the value of the node by accessing the attribute.

        Parameters
        ----------
        execution_context : ExecutionContext
            helper class for evaluating the value of the node.
        args
            argument list for the node.
        kwargs
            keyword arguments for the Node.

        Returns
        -------
        Any
            the value of the accessible attribute.
        """

        assert len(args) == 2, f"Expected 2 args, got {len(args)}"
        obj, attr = args
        if not hasattr(obj, attr):
            raise AttributeError("missing attribute %s" % attr)
        return getattr(obj, attr)
